@@ -14,7 +14,6 @@ from __future__ import unicode_literals
 import numpy as np
 import abel
 
-import collections
 import matplotlib.pylab as plt
 from time import time
 
@@ -22,19 +21,17 @@ from time import time
 #   dictionary of method: function()
 
 transforms = {
-  "direct": abel.direct.direct_transform,      
-  "onion": abel.dasch.onion_peeling_transform, 
-  "hansenlaw": abel.hansenlaw.hansenlaw_transform,
-  "basex": abel.basex.basex_transform,   
-  "three_point": abel.dasch.three_point_transform,
+    "direct": abel.direct.direct_transform,
+    "onion": abel.dasch.onion_peeling_transform,
+    "hansenlaw": abel.hansenlaw.hansenlaw_transform,
+    "basex": abel.basex.basex_transform,
+    "three_point": abel.dasch.three_point_transform,
 }
-# sort dictionary 
-transforms = collections.OrderedDict(sorted(transforms.items()))
-ntrans = np.size(transforms.keys())  # number of transforms
+ntrans = len(transforms)  # number of transforms
 
 
 # Image:   O2- VMI 1024x1024 pixel ------------------
-IM = abel.tools.analytical.SampleImage(n=501, name="Ominus").image
+IM = abel.tools.analytical.SampleImage(n=501, name="Ominus").func
 
 h, w = IM.shape
 
@@ -43,8 +40,8 @@ fIM = abel.Transform(IM, direction="forward", method="hansenlaw").transform
 
 Q0, Q1, Q2, Q3 = abel.tools.symmetry.get_image_quadrants(fIM, reorient=True)
 
-Q0fresh = Q0.copy()    # keep clean copy
-print ("quadrant shape {}".format(Q0.shape))
+Q0fresh = Q0.copy()  # keep clean copy
+print("quadrant shape {}".format(Q0.shape))
 
 # process Q0 quadrant using each method --------------------
 
@@ -54,17 +51,17 @@ iabelQ = []  # keep inverse Abel transformed image
 ax_im = plt.subplot(121)
 ax_sp = plt.subplot(122)
 
-for q, method in enumerate(transforms.keys()):
+for q, method in enumerate(sorted(transforms.keys())):
 
     Q0 = Q0fresh.copy()   # top-right quadrant of O2- image
 
-    print ("\n------- {:s} inverse ...".format(method))  
+    print("\n------- {:s} inverse ...".format(method))
     t0 = time()
 
     # inverse Abel transform using 'method'
     IAQ0 = transforms[method](Q0, direction="inverse")
 
-    print ("                    {:.1f} s".format(time()-t0))
+    print("                    {:.1f} s".format(time()-t0))
 
     iabelQ.append(IAQ0)  # store for plot
 
@@ -72,14 +69,14 @@ for q, method in enumerate(transforms.keys()):
     radial, speed = abel.tools.vmi.angular_integration_3D(IAQ0, origin=(-1, 0))
 
     # normalize image intensity and speed distribution
-    IAQ0 /= IAQ0.max()  
+    IAQ0 /= IAQ0.max()
     speed /= speed.max()
 
     # method label for each quadrant
     annot_angle = -(45+q*90)*np.pi/180  # -ve because numpy coords from top
-    if q > 3: 
-        annot_angle += 50*np.pi/180    # shared quadrant - move the label  
-    annot_coord = (h/2+(h*0.9)*np.cos(annot_angle)/2, 
+    if q > 3:
+        annot_angle += 50*np.pi/180    # shared quadrant - move the label
+    annot_coord = (h/2+(h*0.9)*np.cos(annot_angle)/2,
                    w/2+(w*0.9)*np.sin(annot_angle)/2)
     ax_im.annotate(method, annot_coord, color="yellow")
 
@@ -89,7 +86,7 @@ for q, method in enumerate(transforms.keys()):
 # reassemble image, each quadrant a different method
 
 # for < 4 images pad using a blank quadrant
-blank = np.zeros(IAQ0.shape)  
+blank = np.zeros(IAQ0.shape)
 for q in range(ntrans, 4):
     iabelQ.append(blank)
 
@@ -100,11 +97,11 @@ if ntrans == 5:
               np.triu(np.flipud(iabelQ[-1]))
     iabelQ[3] = np.flipud(tmp_img)
 # Fix me when > 5 images
- 
+
 
 im = abel.tools.symmetry.put_image_quadrants((iabelQ[0], iabelQ[1],
-                                              iabelQ[2], iabelQ[3]), 
-                                              original_image_shape=IM.shape)
+                                              iabelQ[2], iabelQ[3]),
+                                             original_image_shape=IM.shape)
 
 ax_im.imshow(im, vmin=0, vmax=0.8)
 
@@ -112,5 +109,5 @@ plt.title("Ominus sample image")
 ax_sp.axis(ymin=-0.05, ymax=1.1)
 ax_sp.legend(loc=0, labelspacing=0.1)
 plt.tight_layout()
-plt.savefig('plot_example_all_Ominus.png', dpi=100)
+# plt.savefig('plot_example_all_Ominus.png', dpi=100)
 plt.show()
