@@ -12,7 +12,7 @@ import matplotlib.pyplot as plt
 
 # Dribinski sample image size 501x501
 n = 501
-IM = abel.tools.analytical.SampleImage(n).image
+IM = abel.tools.analytical.SampleImage(n).func
 
 # split into quadrants
 origQ = abel.tools.symmetry.get_image_quadrants(IM)
@@ -21,7 +21,7 @@ origQ = abel.tools.symmetry.get_image_quadrants(IM)
 orig_speed = abel.tools.vmi.angular_integration_3D(origQ[0], origin=(-1, 0))
 scale_factor = orig_speed[1].max()
 
-plt.plot(orig_speed[0], orig_speed[1]/scale_factor, linestyle='dashed', 
+plt.plot(orig_speed[0], orig_speed[1]/scale_factor, linestyle='dashed',
          label="Dribinski sample")
 
 
@@ -31,10 +31,11 @@ fIM = abel.Transform(IM, direction="forward", method="hansenlaw").transform
 # split projected image into quadrants
 Q = abel.tools.symmetry.get_image_quadrants(fIM)
 
-dasch_transform = {\
-"two_point": abel.dasch.two_point_transform,
-"three_point": abel.dasch.three_point_transform, 
-"onion_peeling": abel.dasch.onion_peeling_transform}
+dasch_transform = {
+    "two_point": abel.dasch.two_point_transform,
+    "three_point": abel.dasch.three_point_transform,
+    "onion_peeling": abel.dasch.onion_peeling_transform
+}
 
 for method in dasch_transform.keys():
     Q0 = Q[0].copy()
@@ -43,11 +44,12 @@ for method in dasch_transform.keys():
 # speed distribution
     speed = abel.tools.vmi.angular_integration_3D(AQ0, origin=(-1, 0))
 
-    plt.plot(speed[0], speed[1]*orig_speed[1][14]/speed[1][14]/scale_factor, 
+    plt.plot(speed[0], speed[1]*orig_speed[1][14]/speed[1][14]/scale_factor,
              label=method)
 
 plt.title("Dasch methods for Dribinski sample image $n={:d}$".format(n))
-plt.axis(xmax=250, ymin=-0.1)
-plt.legend(loc=0, frameon=False, labelspacing=0.1, fontsize='small')
-plt.savefig("plot_example_dasch_methods.png",dpi=100)
+plt.xlim((0, 250))
+plt.legend(loc='upper center', bbox_to_anchor=(0.35, 1), frameon=False)
+plt.tight_layout()
+# plt.savefig("plot_example_dasch_methods.png",dpi=100)
 plt.show()
