@@ -13,8 +13,7 @@ import matplotlib.pyplot as plt
 import abel
 
 import scipy.misc
-from scipy.ndimage.interpolation import shift
-from scipy.ndimage import zoom
+from scipy.ndimage import shift, zoom
 import bz2
 
 # This example demonstrates both Hansen and Law inverse Abel transform
@@ -45,18 +44,18 @@ im = np.loadtxt(imagefile)
 print("scaling image to size 501 reduce the time of the basis set calculation")
 im = zoom(im, 0.4892578125)
 (rows, cols) = np.shape(im)
-if cols%2 == 0:
-    print ("Even pixel image cols={:d}, adjusting image centre\n",
-           " center_image()".format(cols))
-    im = abel.tools.center.center_image(im, center="slice", odd_size=True)
+if cols % 2 == 0:
+    print("Even pixel image cols={:d}, adjusting image centre\n"
+          " center_image()".format(cols))
+    im = abel.tools.center.center_image(im, origin="slice", odd_size=True)
     # alternative
-    #im = shift(im,(0.5,0.5))
+    #im = shift(im,(0.5, 0.5))
     #im = im[:-1, 1::]  # drop left col, bottom row
-    (rows,cols) = np.shape(im)
+    (rows, cols) = np.shape(im)
 
 c2 = cols//2   # half-image width
 r2 = rows//2   # half-image height
-print ('image size {:d}x{:d}'.format(rows,cols))
+print('image size {:d}x{:d}'.format(rows, cols))
 
 # Hansen & Law inverse Abel transform
 print('Performing Hansen and Law inverse Abel transform:')
@@ -74,43 +73,43 @@ rB, speedsB = abel.tools.vmi.angular_integration_3D(reconB)
 
 # plot the results - VMI, inverse Abel transformed image, speed profiles
 # Set up some axes
-fig = plt.figure(figsize=(15,4))
+fig = plt.figure(figsize=(15, 4.5))
 ax1 = plt.subplot(131)
 ax2 = plt.subplot(132)
 ax3 = plt.subplot(133)
 
 # Plot the raw data
-im1 = ax1.imshow(im, origin='lower', aspect='auto')
-fig.colorbar(im1, ax=ax1, fraction=.1, shrink=0.9, pad=0.03)
+im1 = ax1.imshow(im, origin='lower')
+fig.colorbar(im1, ax=ax1, fraction=0.1, shrink=0.9, pad=0.03)
 ax1.set_xlabel('x (pixels)')
 ax1.set_ylabel('y (pixels)')
 ax1.set_title('velocity map image: size {:d}x{:d}'.format(rows, cols))
 
 # Plot the 2D transform
-reconH2 = reconH[:,:c2]
-reconB2 = reconB[:,c2:]
-recon = np.concatenate((reconH2,reconB2), axis=1)
-im2 = ax2.imshow(recon, origin='lower', aspect='auto', vmin=0,
-                 vmax=recon[:r2-50,:c2-50].max())
-fig.colorbar(im2, ax=ax2, fraction=.1, shrink=0.9, pad=0.03)
+reconH2 = reconH[:, :c2]
+reconB2 = reconB[:, c2:]
+recon = np.concatenate((reconH2, reconB2), axis=1)
+im2 = ax2.imshow(recon, origin='lower', vmin=0,
+                 vmax=recon[:r2-50, :c2-50].max())
+fig.colorbar(im2, ax=ax2, fraction=0.1, shrink=0.9, pad=0.03)
 ax2.set_xlabel('x (pixels)')
 ax2.set_ylabel('y (pixels)')
-ax2.set_title('Hansen Law | Basex',x=0.4)
+ax2.set_title('Hansen–Law | Basex', x=0.43)
 
 # Plot the 1D speed distribution - normalized
 ax3.plot(rB, speedsB/speedsB[150:].max(), 'r-', label="Basex")
-ax3.plot(rH, speedsH/speedsH[150:].max(), 'b-', label="Hansen Law")
-ax3.axis(xmax=250, ymin=-0.1, ymax=1.5)
+ax3.plot(rH, speedsH/speedsH[150:].max(), 'b-', label="Hansen–Law")
+ax3.set_xlim((0, 250))
 ax3.set_xlabel('speed (pixel)')
 ax3.set_ylabel('intensity')
 ax3.set_title('speed distribution')
 ax3.legend(labelspacing=0.1, fontsize='small')
 
 # Prettify the plot a little bit:
-plt.subplots_adjust(left=0.06, bottom=0.17, right=0.95, top=0.89, wspace=0.35, hspace=0.37)
+plt.tight_layout()
 
 # Save a image of the plot
-plt.savefig(output_plot, dpi=150)
+# plt.savefig(output_plot, dpi=150)
 
 # Show the plots
 plt.show()
