@@ -8,7 +8,7 @@ import abel
 import matplotlib.pyplot as plt
 
 # Dribinski sample image
-IM = abel.tools.analytical.SampleImage(n=501).image 
+IM = abel.tools.analytical.SampleImage(n=501).func
 
 # split into quadrants
 origQ = abel.tools.symmetry.get_image_quadrants(IM)
@@ -30,7 +30,8 @@ bor_speed = abel.tools.vmi.angular_integration_3D(borQ0, origin=(-1, 0))
 
 plt.plot(*orig_speed, linestyle='dashed', label="Dribinski sample")
 plt.plot(bor_speed[0], bor_speed[1], label="onion_bordas")
-plt.axis(ymin=-0.1)
+plt.xlim((0, 300))
 plt.legend(loc=0)
-plt.savefig("plot_example_onion_bordas.png",dpi=100)
+plt.tight_layout()
+# plt.savefig("plot_example_onion_bordas.png",dpi=100)
 plt.show()
